@@ -15,6 +15,8 @@
 #include "control/jobs/BaseExportJob.h"  // for ExportBackgroundType
 #include "pdf/base/PdfExportBackend.h"
 
+#include "filesystem.h"
+
 class Document;
 
 namespace ExportHelper {
@@ -35,7 +37,7 @@ namespace ExportHelper {
  *
  * @return 0 on success, -2 on failure opening the input file, -3 on export failure
  */
-int exportImg(Document* doc, const char* output, const char* range, const char* layerRange, int pngDpi, int pngWidth,
+int exportImg(Document* doc, fs::path output, const char* range, const char* layerRange, int pngDpi, int pngWidth,
               int pngHeight, ExportBackgroundType exportBackground);
 
 /**
@@ -52,7 +54,7 @@ int exportImg(Document* doc, const char* output, const char* range, const char*
  *
  * @return 0 on success, -2 on failure opening the input file, -3 on export failure
  */
-int exportPdf(Document* doc, const char* output, const char* range, const char* layerRange,
+int exportPdf(Document* doc, const fs::path& output, const char* range, const char* layerRange,
               ExportBackgroundType exportBackground, bool progressiveMode,
               ExportBackend backend = ExportBackend::DEFAULT);
 
