@@ -4,10 +4,9 @@
 
 #include "AbstractInputHandler.h"
 
-#include <cmath>  // for round
 #include <string_view>
 
-#include <glib.h>  // for gdouble, g_assert
+#include <glib.h>  // for gdouble
 
 #include "control/settings/Settings.h"           // for Settings
 #include "gui/Layout.h"                          // for Layout
@@ -18,6 +17,8 @@
 #include "gui/inputdevices/PositionInputData.h"  // for PositionInputData
 #include "gui/widgets/XournalWidget.h"           // for GtkXournal
 #include "model/Point.h"                         // for Point, Point::NO_PRE...
+#include "util/Assert.h"                         // for xoj_assert
+#include "util/safe_casts.h"                     // for round_cast
 
 #include "InputContext.h"  // for InputContext
 
@@ -41,7 +42,9 @@ auto AbstractInputHandler::isBlocked() const -> bool { return this->blocked; }
 
 auto AbstractInputHandler::handle(InputEvent const& event) -> bool {
     if (!this->blocked) {
-        this->inputContext->getXournal()->view->getCursor()->setInputDeviceClass(event.deviceClass);
+        if (auto* v = this->inputContext->getView(); v) {
+            v->getCursor()->setInputDeviceClass(event.deviceClass);
+        }
         return this->handleImpl(event);
     }
     return true;
@@ -52,15 +55,15 @@ auto AbstractInputHandler::handle(InputEvent const& event) -> bool {
  *
  * @return page or nullptr if none
  */
-auto AbstractInputHandler::getPageAtCurrentPosition(InputEvent const& event) -> XojPageView* {
+auto AbstractInputHandler::getPageAtCurrentPosition(InputEvent const& event) const -> XojPageView* {
     if (!event) {
         return nullptr;
     }
 
     GtkXournal* xournal = this->inputContext->getXournal();
 
-    int x = static_cast<int>(std::round(event.relativeX));
-    int y = static_cast<int>(std::round(event.relativeY));
+    int x = round_cast<int>(event.relative.x);
+    int y = round_cast<int>(event.relative.y);
 
     return xournal->layout->getPageViewAt(x, y);
 }
@@ -68,23 +71,20 @@ auto AbstractInputHandler::getPageAtCurrentPosition(InputEvent const& event) ->
 /**
  * Get input data relative to current input page
  */
-auto AbstractInputHandler::getInputDataRelativeToCurrentPage(XojPageView* page, InputEvent const& event)
+auto AbstractInputHandler::getInputDataRelativeToCurrentPage(XojPageView* page, InputEvent const& event) const
         -> PositionInputData {
-    g_assert(page != nullptr);
-
-    gdouble eventX = event.relativeX;
-    gdouble eventY = event.relativeY;
+    xoj_assert(page != nullptr);
 
     PositionInputData pos = {};
-    pos.x = eventX - static_cast<double>(page->getX());
-    pos.y = eventY - static_cast<double>(page->getY());
+    pos.x = event.relative.x - static_cast<double>(page->getX());
+    pos.y = event.relative.y - static_cast<double>(page->getY());
     pos.pressure = Point::NO_PRESSURE;
 
     if (this->inputContext->getSettings()->isPressureSensitivity()) {
         pos.pressure = event.pressure;
     }
 
-    pos.state = this->inputContext->getModifierState();
+    pos.state = event.state;
     pos.timestamp = event.timestamp;
 
     pos.deviceId = event.deviceId;
