@@ -3,13 +3,9 @@
 #include <gdk/gdk.h>      // for gdk_cursor_new_for_display, gdk_display_get...
 #include <glib-object.h>  // for g_object_unref
 
-AbstractSidebarPage::AbstractSidebarPage(Control* control, SidebarToolbar* toolbar):
-        control(control), toolbar(toolbar) {}
+AbstractSidebarPage::AbstractSidebarPage(Control* control): control(control) {}
 
-AbstractSidebarPage::~AbstractSidebarPage() {
-    this->control = nullptr;
-    this->toolbar = nullptr;
-}
+AbstractSidebarPage::~AbstractSidebarPage() = default;
 
 void AbstractSidebarPage::selectPageNr(size_t page, size_t pdfPage) {}
 
